diff -ruN chocolate-doom-2.3.0-orig/src/i_video.c chocolate-doom-2.3.0/src/i_video.c
--- chocolate-doom-2.3.0-orig/src/i_video.c	2016-12-29 16:54:42.000000000 +0000
+++ chocolate-doom-2.3.0/src/i_video.c	2021-09-06 23:11:07.620405528 +0100
@@ -909,6 +909,76 @@
     return result;
 }
 
+
+// From the SDL documentation on writing directly to display.
+// https://www.libsdl.org/release/SDL-1.2.15/docs/html/guidevideo.html#AEN86
+Uint32 getpixel(SDL_Surface *surface, int x, int y)
+{
+    int bpp = surface->format->BytesPerPixel;
+    /* Here p is the address to the pixel we want to retrieve */
+    Uint8 *p = (Uint8 *)surface->pixels + y * surface->pitch + x * bpp;
+
+    switch(bpp) {
+    case 1:
+        return *p;
+        break;
+
+    case 2:
+        return *(Uint16 *)p;
+        break;
+
+    case 3:
+        if(SDL_BYTEORDER == SDL_BIG_ENDIAN)
+            return p[0] << 16 | p[1] << 8 | p[2];
+        else
+            return p[0] | p[1] << 8 | p[2] << 16;
+        break;
+
+    case 4:
+        return *(Uint32 *)p;
+        break;
+
+    default:
+        return 0;       /* shouldn't happen, but avoids warnings */
+    }
+}
+
+// From the SDL documentation on writing directly to display.
+// https://www.libsdl.org/release/SDL-1.2.15/docs/html/guidevideo.html#AEN86
+void putpixel(SDL_Surface *surface, int x, int y, Uint32 pixel)
+{
+    int bpp = surface->format->BytesPerPixel;
+    /* Here p is the address to the pixel we want to set */
+    Uint8 *p = (Uint8 *)surface->pixels + y * surface->pitch + x * bpp;
+
+    switch(bpp) {
+    case 1:
+        *p = pixel;
+        break;
+
+    case 2:
+        *(Uint16 *)p = pixel;
+        break;
+
+    case 3:
+        if(SDL_BYTEORDER == SDL_BIG_ENDIAN) {
+            p[0] = (pixel >> 16) & 0xff;
+            p[1] = (pixel >> 8) & 0xff;
+            p[2] = pixel & 0xff;
+        } else {
+            p[0] = pixel & 0xff;
+            p[1] = (pixel >> 8) & 0xff;
+            p[2] = (pixel >> 16) & 0xff;
+        }
+        break;
+
+    case 4:
+        *(Uint32 *)p = pixel;
+        break;
+    }
+}
+
+
 //
 // I_FinishUpdate
 //
@@ -962,6 +1032,19 @@
 
     BlitArea(0, 0, SCREENWIDTH, SCREENHEIGHT);
 
+
+	// Flip and mirror the screenbuffer.
+	SDL_LockSurface(screenbuffer);
+	SDL_Surface *tmp_screenbuffer = SDL_ConvertSurface(screenbuffer, screenbuffer->format, SDL_SWSURFACE);
+	for (int y = 0; y < screenbuffer->h; y++) {
+		for (int x = 0; x < screenbuffer->w; x++) {
+			putpixel(screenbuffer, x, y, getpixel(tmp_screenbuffer, screenbuffer->w - x - 1, screenbuffer->h - y - 1) );
+		}
+	}
+	SDL_UnlockSurface(screenbuffer);
+	SDL_FreeSurface(tmp_screenbuffer);
+
+
     if (palette_to_set)
     {
         SDL_SetColors(screenbuffer, palette, 0, 256);
